Index: /issm/trunk/src/mex/ContourToMesh/ContourToMesh.cpp
===================================================================
--- /issm/trunk/src/mex/ContourToMesh/ContourToMesh.cpp	(revision 8305)
+++ /issm/trunk/src/mex/ContourToMesh/ContourToMesh.cpp	(revision 8306)
@@ -84,5 +84,5 @@
 		printf("\nContour echo: contour number  %i / %i\n",i+1,numcontours);
 		contouri=*(contours+i);
-		printf("   Number of grids %i\n",contouri->nods);
+		printf("   Number of vertices %i\n",contouri->nods);
 		for (j=0;j<contouri->nods;j++){
 			printf("   %lf %lf\n",*(contouri->x+j),*(contouri->y+j));
Index: /issm/trunk/src/mex/ContourToNodes/ContourToNodes.cpp
===================================================================
--- /issm/trunk/src/mex/ContourToNodes/ContourToNodes.cpp	(revision 8305)
+++ /issm/trunk/src/mex/ContourToNodes/ContourToNodes.cpp	(revision 8306)
@@ -84,5 +84,5 @@
 		printf("\nContour echo: contour number  %i / %i\n",i+1,numcontours);
 		contouri=*(contours+i);
-		printf("   Number of grids %i\n",contouri->nods);
+		printf("   Number of nodes %i\n",contouri->nods);
 		for (j=0;j<contouri->nods;j++){
 			printf("   %lf %lf\n",*(contouri->x+j),*(contouri->y+j));
Index: /issm/trunk/src/mex/InterpFromMeshToMesh2d/InterpFromMeshToMesh2d.cpp
===================================================================
--- /issm/trunk/src/mex/InterpFromMeshToMesh2d/InterpFromMeshToMesh2d.cpp	(revision 8305)
+++ /issm/trunk/src/mex/InterpFromMeshToMesh2d/InterpFromMeshToMesh2d.cpp	(revision 8306)
@@ -94,5 +94,5 @@
 		  printf("\nContour echo: contour number  %i / %i\n",i+1,numcontours);
 		  contouri=*(contours+i);
-		  printf("   Number of grids %i\n",contouri->nods);
+		  printf("   Number of vertices %i\n",contouri->nods);
 		  for (j=0;j<contouri->nods;j++){
 		  printf("   %lf %lf\n",*(contouri->x+j),*(contouri->y+j));
Index: /issm/trunk/src/mex/MeshPartition/MeshPartition.cpp
===================================================================
--- /issm/trunk/src/mex/MeshPartition/MeshPartition.cpp	(revision 8305)
+++ /issm/trunk/src/mex/MeshPartition/MeshPartition.cpp	(revision 8306)
@@ -7,5 +7,5 @@
 	%Info needed from model are the following: 
 	%mesh info: 
-	numberofelements,numberofgrids,elements,elements_width
+	numberofelements,numberofnodes,elements,elements_width
 	%Non-extruded 2d mesh info
 	nel2d,nods2d,elements2d,
@@ -32,10 +32,10 @@
 	int dim;
 	int numberofelements;
-	int numberofgrids;
+	int numberofnodes;
 	double* elements=NULL;
 	int     elements_width;
 
 	int numberofelements2d;
-	int numberofgrids2d;
+	int numberofnodes2d;
 	double* elements2d=NULL;
 
@@ -59,5 +59,5 @@
 	FetchData(&dim,mxGetAssignedField(MODEL,0,"dim"));
 	FetchData(&numberofelements,mxGetAssignedField(MODEL,0,"numberofelements"));
-	FetchData(&numberofgrids,mxGetAssignedField(MODEL,0,"numberofgrids"));
+	FetchData(&numberofnodes,mxGetAssignedField(MODEL,0,"numberofnodes"));
 	FetchData(&elements,NULL,&elements_width,mxGetAssignedField(MODEL,0,"elements"));
 
@@ -65,5 +65,5 @@
 	
 		FetchData(&numberofelements2d,mxGetAssignedField(MODEL,0,"numberofelements2d"));
-		FetchData(&numberofgrids2d,mxGetAssignedField(MODEL,0,"numberofgrids2d"));
+		FetchData(&numberofnodes2d,mxGetAssignedField(MODEL,0,"numberofnodes2d"));
 		FetchData(&elements2d,NULL,NULL,mxGetAssignedField(MODEL,0,"elements2d"));
 
@@ -73,6 +73,6 @@
 
 	/*Run partitioning algorithm based on a "clever" use of the Metis partitioner: */
-	MeshPartitionx(&int_element_partitioning,&int_node_partitioning,numberofelements,numberofgrids,elements,
-		numberofelements2d,numberofgrids2d,elements2d,numlayers,elements_width,dim,numareas);
+	MeshPartitionx(&int_element_partitioning,&int_node_partitioning,numberofelements,numberofnodes,elements,
+		numberofelements2d,numberofnodes2d,elements2d,numlayers,elements_width,dim,numareas);
 
 
@@ -83,6 +83,6 @@
 	}
 	
-	node_partitioning=(double*)xmalloc(numberofgrids*sizeof(double));
-	for (i=0;i<numberofgrids;i++){
+	node_partitioning=(double*)xmalloc(numberofnodes*sizeof(double));
+	for (i=0;i<numberofnodes;i++){
 		node_partitioning[i]=(double)int_node_partitioning[i]+1; //Metis indexing from 0, matlab from 1.
 	}
@@ -90,5 +90,5 @@
 	/*Write data:*/
 	WriteData(ELEMENTPARTITIONING,element_partitioning,numberofelements);
-	WriteData(NODEPARTITIONING,node_partitioning,numberofgrids);
+	WriteData(NODEPARTITIONING,node_partitioning,numberofnodes);
 	
 	/*Free ressources:*/
Index: /issm/trunk/src/mex/MeshProfileIntersection/MeshProfileIntersection.cpp
===================================================================
--- /issm/trunk/src/mex/MeshProfileIntersection/MeshProfileIntersection.cpp	(revision 8305)
+++ /issm/trunk/src/mex/MeshProfileIntersection/MeshProfileIntersection.cpp	(revision 8306)
@@ -83,5 +83,5 @@
 		printf("\nContour echo: contour number  %i / %i\n",i+1,numcontours);
 		contouri=*(contours+i);
-		printf("   Number of grids %i\n",contouri->nods);
+		printf("   Number of vertices %i\n",contouri->nods);
 		for (j=0;j<contouri->nods;j++){
 			printf("   %lf %lf\n",*(contouri->x+j),*(contouri->y+j));
Index: /issm/trunk/src/mex/ModelProcessor/ModelProcessor.cpp
===================================================================
--- /issm/trunk/src/mex/ModelProcessor/ModelProcessor.cpp	(revision 8305)
+++ /issm/trunk/src/mex/ModelProcessor/ModelProcessor.cpp	(revision 8306)
@@ -66,5 +66,5 @@
 void ModelProcessorUsage(void) {
 	_printf_(true,"\n");
-	_printf_(true,"   usage: [elements,grids,constraints,loads,materials,parameters,part,tpart]=ModelProcessor(model,analyses)\n");
+	_printf_(true,"   usage: [elements,vertices,constraints,loads,materials,parameters,part,tpart]=ModelProcessor(model,analyses)\n");
 	_printf_(true,"   where: model is an instance of the matlab @model class and analyses is a list of analysis types being performed.\n");
 	_printf_(true,"\n");
Index: /issm/trunk/src/mex/TriMesh/TriMesh.cpp
===================================================================
--- /issm/trunk/src/mex/TriMesh/TriMesh.cpp	(revision 8305)
+++ /issm/trunk/src/mex/TriMesh/TriMesh.cpp	(revision 8306)
@@ -35,5 +35,5 @@
 	/*Domain outline variables: */
 	int      nprof;
-	int*     profngrids=NULL;
+	int*     profnvertices=NULL;
 	double** pprofx=NULL;
 	double** pprofy=NULL;
@@ -44,7 +44,7 @@
 	/*Rift outline variables: */
 	int      numrifts;
-	int*     riftsnumgrids=NULL;
-	double** riftsgridsx=NULL;
-	double** riftsgridsy=NULL;
+	int*     riftsnumvertices=NULL;
+	double** riftsverticesx=NULL;
+	double** riftsverticesy=NULL;
 
 	/* Triangle structures: */
@@ -96,5 +96,5 @@
 	
 	/*Start reading the domain outline file: */
-	if(!DomainOutlineRead(&nprof,&profngrids,&pprofx,&pprofy,domainname)){
+	if(!DomainOutlineRead(&nprof,&profnvertices,&pprofx,&pprofy,domainname)){
 		printf("%s%s%s\n",__FUNCT__," error message reading domain outline ",domainname);
 		mexErrMsgTxt(" ");
@@ -103,5 +103,5 @@
 	/*Read rifts file if present: */
 	if(riftname){
-		if(!DomainOutlineRead(&numrifts,&riftsnumgrids,&riftsgridsx,&riftsgridsy,riftname)){
+		if(!DomainOutlineRead(&numrifts,&riftsnumvertices,&riftsverticesx,&riftsverticesy,riftname)){
 			printf("%s%s%s\n",__FUNCT__," error message reading rifts outline ",riftname);
 			mexErrMsgTxt(" ");
@@ -112,9 +112,9 @@
 	numberofpoints=0;
 	for (i=0;i<nprof;i++){
-		numberofpoints+=profngrids[i];
+		numberofpoints+=profnvertices[i];
 	}
 	if (riftname){
 		for (i=0;i<numrifts;i++){
-			numberofpoints+=riftsnumgrids[i];
+			numberofpoints+=riftsnumvertices[i];
 		}
 	}
@@ -128,5 +128,5 @@
 		xprof=pprofx[i];
 		yprof=pprofy[i];
-		for (j=0;j<profngrids[i];j++){
+		for (j=0;j<profnvertices[i];j++){
 			in.pointlist[2*counter+0]=xprof[j];
 			in.pointlist[2*counter+1]=yprof[j];
@@ -136,7 +136,7 @@
 	if(riftname){
 		for (i=0;i<numrifts;i++){
-			xprof=riftsgridsx[i];
-			yprof=riftsgridsy[i];
-			for (j=0;j<riftsnumgrids[i];j++){
+			xprof=riftsverticesx[i];
+			yprof=riftsverticesy[i];
+			for (j=0;j<riftsnumvertices[i];j++){
 				in.pointlist[2*counter+0]=xprof[j];
 				in.pointlist[2*counter+1]=yprof[j];
@@ -158,13 +158,13 @@
 
 	/*Build segments: */
-	/*Figure out number of segments: holes and closed outlines have as many segments as grids, 
-	 *for rifts, we have one less segment as we have grids*/
+	/*Figure out number of segments: holes and closed outlines have as many segments as vertices, 
+	 *for rifts, we have one less segment as we have vertices*/
 	in.numberofsegments=0;
 	for (i=0;i<nprof;i++){
-		in.numberofsegments+=profngrids[i];
+		in.numberofsegments+=profnvertices[i];
 	}
 	if (riftname){
 		for (i=0;i<numrifts;i++){
-			in.numberofsegments+=riftsnumgrids[i]-1;
+			in.numberofsegments+=riftsnumvertices[i]-1;
 		}
 	}
@@ -175,5 +175,5 @@
 	backcounter=0;
 	for (i=0;i<nprof;i++){
-		for (j=0;j<(profngrids[i]-1);j++){
+		for (j=0;j<(profnvertices[i]-1);j++){
 			in.segmentlist[2*counter+0]=counter;
 			in.segmentlist[2*counter+1]=counter+1;
@@ -191,5 +191,5 @@
 	if(riftname){
 		for (i=0;i<numrifts;i++){
-			for (j=0;j<(riftsnumgrids[i]-1);j++){
+			for (j=0;j<(riftsnumvertices[i]-1);j++){
 				in.segmentlist[2*counter2+0]=counter;
 				in.segmentlist[2*counter2+1]=counter+1;
@@ -210,6 +210,6 @@
 	in.holelist = (REAL *) mxMalloc(in.numberofholes * 2 * sizeof(REAL));
 	for (i=0;i<nprof-1;i++){
-		/*We are looking for a grid that lies inside the hole: */
-		GridInsideHole(&in.holelist[2*i+0],&in.holelist[2*i+1],profngrids[i+1],pprofx[i+1],pprofy[i+1]);
+		/*We are looking for a vertex that lies inside the hole: */
+		GridInsideHole(&in.holelist[2*i+0],&in.holelist[2*i+1],profnvertices[i+1],pprofx[i+1],pprofy[i+1]);
 	}
 
Index: /issm/trunk/src/mex/TriMeshNoDensity/TriMeshNoDensity.cpp
===================================================================
--- /issm/trunk/src/mex/TriMeshNoDensity/TriMeshNoDensity.cpp	(revision 8305)
+++ /issm/trunk/src/mex/TriMeshNoDensity/TriMeshNoDensity.cpp	(revision 8306)
@@ -33,5 +33,5 @@
 	/*Domain outline variables: */
 	int      nprof;
-	int*     profngrids=NULL;
+	int*     profnvertices=NULL;
 	double** pprofx=NULL;
 	double** pprofy=NULL;
@@ -42,7 +42,7 @@
 	/*Rift outline variables: */
 	int      numrifts;
-	int*     riftsnumgrids=NULL;
-	double** riftsgridsx=NULL;
-	double** riftsgridsy=NULL;
+	int*     riftsnumvertices=NULL;
+	double** riftsverticesx=NULL;
+	double** riftsverticesy=NULL;
 
 	/* Triangle structures: */
@@ -86,5 +86,5 @@
 	
 	/*Start reading the domain outline file: */
-	if(!DomainOutlineRead(&nprof,&profngrids,&pprofx,&pprofy,domainname)){
+	if(!DomainOutlineRead(&nprof,&profnvertices,&pprofx,&pprofy,domainname)){
 		printf("%s%s%s\n",__FUNCT__," error message reading domain outline ",domainname);
 		mexErrMsgTxt(" ");
@@ -93,5 +93,5 @@
 	/*Read rifts file if present: */
 	if(riftname){
-		if(!DomainOutlineRead(&numrifts,&riftsnumgrids,&riftsgridsx,&riftsgridsy,riftname)){
+		if(!DomainOutlineRead(&numrifts,&riftsnumvertices,&riftsverticesx,&riftsverticesy,riftname)){
 			printf("%s%s%s\n",__FUNCT__," error message reading rifts outline ",riftname);
 			mexErrMsgTxt(" ");
@@ -102,9 +102,9 @@
 	numberofpoints=0;
 	for (i=0;i<nprof;i++){
-		numberofpoints+=profngrids[i];
+		numberofpoints+=profnvertices[i];
 	}
 	if (riftname){
 		for (i=0;i<numrifts;i++){
-			numberofpoints+=riftsnumgrids[i];
+			numberofpoints+=riftsnumvertices[i];
 		}
 	}
@@ -118,5 +118,5 @@
 		xprof=pprofx[i];
 		yprof=pprofy[i];
-		for (j=0;j<profngrids[i];j++){
+		for (j=0;j<profnvertices[i];j++){
 			in.pointlist[2*counter+0]=xprof[j];
 			in.pointlist[2*counter+1]=yprof[j];
@@ -126,7 +126,7 @@
 	if(riftname){
 		for (i=0;i<numrifts;i++){
-			xprof=riftsgridsx[i];
-			yprof=riftsgridsy[i];
-			for (j=0;j<riftsnumgrids[i];j++){
+			xprof=riftsverticesx[i];
+			yprof=riftsverticesy[i];
+			for (j=0;j<riftsnumvertices[i];j++){
 				in.pointlist[2*counter+0]=xprof[j];
 				in.pointlist[2*counter+1]=yprof[j];
@@ -149,13 +149,13 @@
 
 	/*Build segments: */
-	/*Figure out number of segments: holes and closed outlines have as many segments as grids, 
-	 *for rifts, we have one less segment as we have grids*/
+	/*Figure out number of segments: holes and closed outlines have as many segments as vertices, 
+	 *for rifts, we have one less segment as we have vertices*/
 	in.numberofsegments=0;
 	for (i=0;i<nprof;i++){
-		in.numberofsegments+=profngrids[i];
+		in.numberofsegments+=profnvertices[i];
 	}
 	if (riftname){
 		for (i=0;i<numrifts;i++){
-			in.numberofsegments+=riftsnumgrids[i]-1;
+			in.numberofsegments+=riftsnumvertices[i]-1;
 		}
 	}
@@ -166,5 +166,5 @@
 	backcounter=0;
 	for (i=0;i<nprof;i++){
-		for (j=0;j<(profngrids[i]-1);j++){
+		for (j=0;j<(profnvertices[i]-1);j++){
 			in.segmentlist[2*counter+0]=counter;
 			in.segmentlist[2*counter+1]=counter+1;
@@ -182,5 +182,5 @@
 	if(riftname){
 		for (i=0;i<numrifts;i++){
-			for (j=0;j<(riftsnumgrids[i]-1);j++){
+			for (j=0;j<(riftsnumvertices[i]-1);j++){
 				in.segmentlist[2*counter2+0]=counter;
 				in.segmentlist[2*counter2+1]=counter+1;
@@ -201,6 +201,6 @@
 	in.holelist = (REAL *) mxMalloc(in.numberofholes * 2 * sizeof(REAL));
 	for (i=0;i<nprof-1;i++){
-		/*We are looking for a grid that lies inside the hole: */
-		GridInsideHole(&in.holelist[2*i+0],&in.holelist[2*i+1],profngrids[i+1],pprofx[i+1],pprofy[i+1]);
+		/*We are looking for a vertex that lies inside the hole: */
+		GridInsideHole(&in.holelist[2*i+0],&in.holelist[2*i+1],profnvertices[i+1],pprofx[i+1],pprofy[i+1]);
 	}
 
Index: /issm/trunk/src/mex/TriMeshProcessRifts/TriMeshProcessRifts.cpp
===================================================================
--- /issm/trunk/src/mex/TriMeshProcessRifts/TriMeshProcessRifts.cpp	(revision 8305)
+++ /issm/trunk/src/mex/TriMeshProcessRifts/TriMeshProcessRifts.cpp	(revision 8306)
@@ -165,5 +165,5 @@
 
 	/*First, do some fixing on the existing mesh: we do not want any element belonging entirely to the segment list (ie: 
-	 *all the grids of this element belong to the segments (tends to happen when there are corners: */
+	 *all the nodes of this element belong to the segments (tends to happen when there are corners: */
 	RemoveCornersFromRifts(&index_in,&nel,&x_in,&y_in,&nods,segments_in,segmentmarkers_in,num_seg);
 
Index: /issm/trunk/src/mex/TriaSearch/TriaSearch.cpp
===================================================================
--- /issm/trunk/src/mex/TriaSearch/TriaSearch.cpp	(revision 8305)
+++ /issm/trunk/src/mex/TriaSearch/TriaSearch.cpp	(revision 8306)
@@ -19,5 +19,5 @@
 	double* x0=NULL;
 	double* y0=NULL;
-	int     numberofgrids;
+	int     numberofnodes;
 
 	/* output: */
@@ -34,6 +34,6 @@
 	FetchData(&x,&nods,XHANDLE);
 	FetchData(&y,&nods,YHANDLE);
-	FetchData(&x0,&numberofgrids,X0HANDLE);
-	FetchData(&y0,&numberofgrids,Y0HANDLE);
+	FetchData(&x0,&numberofnodes,X0HANDLE);
+	FetchData(&y0,&numberofnodes,Y0HANDLE);
 
 	/* Echo: {{{1*/
@@ -42,11 +42,11 @@
 
 	/* Run core computations: */
-	TriaSearchx(&tria,index,nel,x,y,nods,x0,y0,numberofgrids);
+	TriaSearchx(&tria,index,nel,x,y,nods,x0,y0,numberofnodes);
 
 	/* c to matlab: */
-	for(i=0;i<numberofgrids;i++)tria[i]++;
+	for(i=0;i<numberofnodes;i++)tria[i]++;
 
 	/*Write data: */
-	WriteData(TRIA,tria,numberofgrids);
+	WriteData(TRIA,tria,numberofnodes);
 
 	/*end module: */

Index: /issm/trunk/src/mex/InterpFromGridToMesh/InterpFromGridToMesh.cpp
===================================================================
--- /issm/trunk/src/mex/InterpFromGridToMesh/InterpFromGridToMesh.cpp	(revision 8305)
+++ /issm/trunk/src/mex/InterpFromGridToMesh/InterpFromGridToMesh.cpp	(revision 8306)
@@ -1,4 +1,4 @@
 /*!\file InterpFromGridToMesh.c
  * \brief: data interpolation from a list of (x,y,values) into mesh grids
  
 	InterpFromGridToMesh.c
@@ -12,5 +12,5 @@
 		x,y: coordinates of matrix data
 		data - matrix holding the data to be interpolated onto the mesh.
-		x_mesh,y_mesh: coordinates of the mesh grids onto which we interpolate.
+		x_mesh,y_mesh: coordinates of the mesh vertices onto which we interpolate.
 		
 		output: 
@@ -1,4 +1,4 @@
 /*!\file InterpFromGridToMesh.c
- * \brief: data interpolation from a list of (x,y,values) into mesh grids
+ * \brief: data interpolation from a list of (x,y,values) into mesh vertices
  
 	InterpFromGridToMesh.c
Index: /issm/trunk/src/mex/InterpFromMesh2d/InterpFromMesh2d.cpp
===================================================================
--- /issm/trunk/src/mex/InterpFromMesh2d/InterpFromMesh2d.cpp	(revision 8305)
+++ /issm/trunk/src/mex/InterpFromMesh2d/InterpFromMesh2d.cpp	(revision 8306)
@@ -1,4 +1,4 @@
 /*!\file InterpFromMesh2d.c
  * \brief: data interpolation from a list of (x,y,values) into mesh grids
  
 	InterpFromMesh2d.c
@@ -12,5 +12,5 @@
 		x,y: coordinates of matrix data
 		data - matrix holding the data to be interpolated onto the mesh.
-		x_mesh,y_mesh: coordinates of the mesh grids onto which we interpolate.
+		x_mesh,y_mesh: coordinates of the mesh vertices onto which we interpolate.
 		
 		output: 
@@ -116,5 +116,5 @@
 		  printf("\nContour echo: contour number  %i / %i\n",i+1,numcontours);
 		  contouri=*(contours+i);
-		  printf("   Number of grids %i\n",contouri->nods);
+		  printf("   Number of vertices %i\n",contouri->nods);
 		  for (j=0;j<contouri->nods;j++){
 		  printf("   %lf %lf\n",*(contouri->x+j),*(contouri->y+j));
@@ -162,5 +162,5 @@
 	_printf_(true,"      index: index of the mesh where data is defined\n");
 	_printf_(true,"      data - vector holding the data to be interpolated onto the points.\n");
-	_printf_(true,"      x_prime,y_prime: coordinates of the mesh grids onto which we interpolate.\n");
+	_printf_(true,"      x_prime,y_prime: coordinates of the mesh vertices onto which we interpolate.\n");
 	_printf_(true,"      default_value: a scalar or vector of size length(x_prime).\n");
 	_printf_(true,"      contourname: linear interpolation will happen on all x_interp,y_interp inside the contour, default value will be adopted on the rest of the mesh.\n");
@@ -1,4 +1,4 @@
 /*!\file InterpFromMesh2d.c
- * \brief: data interpolation from a list of (x,y,values) into mesh grids
+ * \brief: data interpolation from a list of (x,y,values) into mesh vertices
  
 	InterpFromMesh2d.c
Index: /issm/trunk/src/mex/InterpFromMeshToMesh3d/InterpFromMeshToMesh3d.cpp
===================================================================
--- /issm/trunk/src/mex/InterpFromMeshToMesh3d/InterpFromMeshToMesh3d.cpp	(revision 8305)
+++ /issm/trunk/src/mex/InterpFromMeshToMesh3d/InterpFromMeshToMesh3d.cpp	(revision 8306)
@@ -1,4 +1,4 @@
 /*!\file InterpFromMeshToMesh3d.c
  * \brief: data interpolation from a list of (x,y,values) into mesh grids
  
 	InterpFromMeshToMesh3d.c
@@ -12,5 +12,5 @@
 		x,y,z: coordinates of matrix data
 		data - matrix holding the data to be interpolated onto the mesh.
-		x_mesh,y_mesh,z_mesh: coordinates of the mesh grids onto which we interpolate.
+		x_mesh,y_mesh,z_mesh: coordinates of the mesh vertices onto which we interpolate.
 		
 		output: 
@@ -1,4 +1,4 @@
 /*!\file InterpFromMeshToMesh3d.c
- * \brief: data interpolation from a list of (x,y,values) into mesh grids
+ * \brief: data interpolation from a list of (x,y,values) into mesh vertices
  
 	InterpFromMeshToMesh3d.c